@@ -1,33 +1,18 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "sink.h"
 
+#include "canberracontext.h"
 #include "context.h"
 #include "server.h"
 #include "sinkinput.h"
-#include "canberracontext.h"
 
 namespace QPulseAudio
 {
-
 Sink::Sink(QObject *parent)
     : Device(parent)
 {
@@ -94,14 +79,15 @@ void Sink::setDefault(bool enable)
 void Sink::testChannel(const QString &name)
 {
     auto context = CanberraContext::instance()->canberra();
-    if (!context)
+    if (!context) {
         return;
+    }
 
     char dev[64];
-    snprintf(dev, sizeof(dev), "%lu", (unsigned long) m_index);
+    snprintf(dev, sizeof(dev), "%lu", (unsigned long)m_index);
     ca_context_change_device(context, dev);
 
-    QString sound_name =  QStringLiteral("audio-channel-") + name;
+    QString sound_name = QStringLiteral("audio-channel-") + name;
     ca_proplist *proplist;
     ca_proplist_create(&proplist);
 
@@ -128,7 +114,7 @@ void Sink::testChannel(const QString &name)
 void Sink::switchStreams()
 {
     auto data = context()->sinkInputs().data();
-    std::for_each(data.begin(), data.end(), [this](SinkInput* paObj) {
+    std::for_each(data.begin(), data.end(), [this](SinkInput *paObj) {
         paObj->setDeviceIndex(m_index);
     });
 }
